==> ejc-purchasingmanagement-impl-3.0.0-20220424.052451-26-sources.jar: com/ejianc/business/purchasingmanagement/bean/PurchasecontractdetailEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 采购合同明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_purchasecontractdetail")
public class PurchasecontractdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="purchasecontract_id")
    private Long purchasecontractId; // 采购合同主键
    @TableField(value="material_id")
    private Long materialId; // 原材类主键
    @TableField(value="material_name")
    private String materialName; // 原材类名称
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="quantity")
    private BigDecimal quantity; // 数量
    @TableField(value="manufacturer_id")
    private Long manufacturerId; // 生产厂商主键
    @TableField(value="manufacturer_name")
    private String manufacturerName; // 生产厂商名称
    @TableField(value="freight")
    private Integer freight; // 有无运费：1有运费 0无
    @TableField(value="distance")
    private Long distance; // 运距
    @TableField(value="shipping_method")
    private Integer shippingMethod; // 运费计算方式
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="material_tax")
    private BigDecimal materialTax; // 材料税率
    @TableField(value="freight_rate")
    private BigDecimal freightRate; // 运费税率
    @TableField(value="sjyf_price")
    private BigDecimal sjyfPrice; // 实际运费单价
    @TableField(value="kpyf_price")
    private BigDecimal kpyfPrice; // 开票运费单价
    @TableField(value="comprehensive_tax_rate")
    private BigDecimal comprehensiveTaxRate; // 综合税率
    @TableField(value="combined_tax")
    private BigDecimal combinedTax; // 结合税额
    @TableField(value="dyyss")
    private String dyyss; // 打印运输商
    @TableField(value="shippers_id")
    private Long shippersId; // 运输商主键
    @TableField(value="shippers_name")
    private String shippersName; // 运输商名称

    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }

    public BigDecimal getMaterialTax() {
        return materialTax;
    }

    public void setMaterialTax(BigDecimal materialTax) {
        this.materialTax = materialTax;
    }

    public BigDecimal getFreightRate() {
        return freightRate;
    }

    public void setFreightRate(BigDecimal freightRate) {
        this.freightRate = freightRate;
    }

    public BigDecimal getComprehensiveTaxRate() {
        return comprehensiveTaxRate;
    }

    public void setComprehensiveTaxRate(BigDecimal comprehensiveTaxRate) {
        this.comprehensiveTaxRate = comprehensiveTaxRate;
    }

    public BigDecimal getCombinedTax() {
        return combinedTax;
    }

    public void setCombinedTax(BigDecimal combinedTax) {
        this.combinedTax = combinedTax;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public Long getPurchasecontractId() {
        return purchasecontractId;
    }

    public void setPurchasecontractId(Long purchasecontractId) {
        this.purchasecontractId = purchasecontractId;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public Long getManufacturerId() {
        return manufacturerId;
    }

    public void setManufacturerId(Long manufacturerId) {
        this.manufacturerId = manufacturerId;
    }
    public String getManufacturerName() {
        return manufacturerName;
    }

    public void setManufacturerName(String manufacturerName) {
        this.manufacturerName = manufacturerName;
    }
    public Integer getFreight() {
        return freight;
    }

    public void setFreight(Integer freight) {
        this.freight = freight;
    }
    public Long getDistance() {
        return distance;
    }

    public void setDistance(Long distance) {
        this.distance = distance;
    }

    public Integer getShippingMethod() {
        return shippingMethod;
    }

    public void setShippingMethod(Integer shippingMethod) {
        this.shippingMethod = shippingMethod;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public BigDecimal getSjyfPrice() {
        return sjyfPrice;
    }

    public void setSjyfPrice(BigDecimal sjyfPrice) {
        this.sjyfPrice = sjyfPrice;
    }
    public BigDecimal getKpyfPrice() {
        return kpyfPrice;
    }

    public void setKpyfPrice(BigDecimal kpyfPrice) {
        this.kpyfPrice = kpyfPrice;
    }

    public String getDyyss() {
        return dyyss;
    }

    public void setDyyss(String dyyss) {
        this.dyyss = dyyss;
    }
    public Long getShippersId() {
        return shippersId;
    }

    public void setShippersId(Long shippersId) {
        this.shippersId = shippersId;
    }
    public String getShippersName() {
        return shippersName;
    }

    public void setShippersName(String shippersName) {
        this.shippersName = shippersName;
    }
    
}

==> ejc-purchasingmanagement-impl-3.0.0-20220511.150614-65-sources.jar: com/ejianc/business/purchasingmanagement/bean/PurchasecontractdetailEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 采购合同明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_purchasecontractdetail")
public class PurchasecontractdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="purchasecontract_id")
    private Long purchasecontractId; // 采购合同主键
    @TableField(value="material_id")
    private Long materialId; // 原材类主键
    @TableField(value="material_name")
    private String materialName; // 原材类名称
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="quantity")
    private BigDecimal quantity; // 数量
    @TableField(value="manufacturer_id")
    private Long manufacturerId; // 生产厂商主键
    @TableField(value="manufacturer_name")
    private String manufacturerName; // 生产厂商名称
    @TableField(value="freight")
    private Integer freight; // 有无运费：1有运费 0无
    @TableField(value="distance")
    private BigDecimal distance; // 运距
    @TableField(value="shipping_method")
    private Integer shippingMethod; // 运费计算方式
    @TableField(value="remark")


    private String remark; // 备注
    @TableField(value="material_tax")
    private BigDecimal materialTax; // 材料税率
    @TableField(value="freight_rate")
    private BigDecimal freightRate; // 运费税率
    @TableField(value="sjyf_price")
    private BigDecimal sjyfPrice; // 实际运费单价
    @TableField(value="kpyf_price")
    private BigDecimal kpyfPrice; // 开票运费单价
    @TableField(value="comprehensive_tax_rate")
    private BigDecimal comprehensiveTaxRate; // 综合税率
    @TableField(value="combined_tax")
    private BigDecimal combinedTax; // 结合税额
    @TableField(value="dyyss")
    private String dyyss; // 打印运输商
    @TableField(value="shippers_id")
    private Long shippersId; // 运输商主键
    @TableField(value="shippers_name")
    private String shippersName; // 运输商名称

    @TableField(value="amount")
    private BigDecimal amount; // 含税金额

    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }

    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }

    public BigDecimal getMaterialTax() {
        return materialTax;
    }

    public void setMaterialTax(BigDecimal materialTax) {
        this.materialTax = materialTax;
    }

    public BigDecimal getFreightRate() {
        return freightRate;
    }

    public void setFreightRate(BigDecimal freightRate) {
        this.freightRate = freightRate;
    }

    public BigDecimal getComprehensiveTaxRate() {
        return comprehensiveTaxRate;
    }

    public void setComprehensiveTaxRate(BigDecimal comprehensiveTaxRate) {
        this.comprehensiveTaxRate = comprehensiveTaxRate;
    }

    public BigDecimal getCombinedTax() {
        return combinedTax;
    }

    public void setCombinedTax(BigDecimal combinedTax) {
        this.combinedTax = combinedTax;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public Long getPurchasecontractId() {
        return purchasecontractId;
    }

    public void setPurchasecontractId(Long purchasecontractId) {
        this.purchasecontractId = purchasecontractId;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public Long getManufacturerId() {
        return manufacturerId;
    }

    public void setManufacturerId(Long manufacturerId) {
        this.manufacturerId = manufacturerId;
    }
    public String getManufacturerName() {
        return manufacturerName;
    }

    public void setManufacturerName(String manufacturerName) {
        this.manufacturerName = manufacturerName;
    }
    public Integer getFreight() {
        return freight;
    }

    public void setFreight(Integer freight) {
        this.freight = freight;
    }

    public BigDecimal getDistance() {
        return distance;
    }

    public void setDistance(BigDecimal distance) {
        this.distance = distance;
    }

    public Integer getShippingMethod() {
        return shippingMethod;
    }

    public void setShippingMethod(Integer shippingMethod) {
        this.shippingMethod = shippingMethod;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public BigDecimal getSjyfPrice() {
        return sjyfPrice;
    }

    public void setSjyfPrice(BigDecimal sjyfPrice) {
        this.sjyfPrice = sjyfPrice;
    }
    public BigDecimal getKpyfPrice() {
        return kpyfPrice;
    }

    public void setKpyfPrice(BigDecimal kpyfPrice) {
        this.kpyfPrice = kpyfPrice;
    }

    public String getDyyss() {
        return dyyss;
    }

    public void setDyyss(String dyyss) {
        this.dyyss = dyyss;
    }
    public Long getShippersId() {
        return shippersId;
    }

    public void setShippersId(Long shippersId) {
        this.shippersId = shippersId;
    }
    public String getShippersName() {
        return shippersName;
    }

    public void setShippersName(String shippersName) {
        this.shippersName = shippersName;
    }
    
}
